@@ -10,8 +10,8 @@
 
 #include "alarmdialog.h"
 #include "alarmdockwindow.h"
-#include "korgacadaptor.h"
 #include "koalarmclient_debug.h"
+#include "korgacadaptor.h"
 
 #include <AkonadiCore/EntityTreeModel>
 #include <AkonadiCore/ServerManager>
@@ -42,8 +42,7 @@ KOAlarmClient::KOAlarmClient(QObject *parent)
     }
 
     // Check if Akonadi is already configured
-    const QString akonadiConfigFile = Akonadi::ServerManager::serverConfigFilePath(
-        Akonadi::ServerManager::ReadWrite);
+    const QString akonadiConfigFile = Akonadi::ServerManager::serverConfigFilePath(Akonadi::ServerManager::ReadWrite);
     if (QFileInfo::exists(akonadiConfigFile)) {
         // Akonadi is configured, create ETM and friends, which will start Akonadi
         // if its not running yet
@@ -51,8 +50,7 @@ KOAlarmClient::KOAlarmClient(QObject *parent)
     } else {
         // Akonadi has not been set up yet, wait for someone else to start it,
         // so that we don't unnecessarily slow session start up
-        connect(Akonadi::ServerManager::self(), &Akonadi::ServerManager::stateChanged,
-                this, [this](Akonadi::ServerManager::State state) {
+        connect(Akonadi::ServerManager::self(), &Akonadi::ServerManager::stateChanged, this, [this](Akonadi::ServerManager::State state) {
             if (state == Akonadi::ServerManager::Running) {
                 setupAkonadi();
             }
@@ -64,7 +62,7 @@ KOAlarmClient::KOAlarmClient(QObject *parent)
     qCDebug(KOALARMCLIENT_LOG) << "KOAlarmClient check interval:" << interval << "seconds.";
     mLastChecked = alarmGroup.readEntry("CalendarsLastChecked", QDateTime::currentDateTime().addDays(-9));
 
-    mCheckTimer.start(1000 * interval);    // interval in seconds
+    mCheckTimer.start(1000 * interval); // interval in seconds
     connect(qApp, &QApplication::commitDataRequest, this, &KOAlarmClient::slotCommitData);
 }
 
@@ -76,19 +74,14 @@ KOAlarmClient::~KOAlarmClient()
 
 void KOAlarmClient::setupAkonadi()
 {
-    const QStringList mimeTypes {
-        Event::eventMimeType(),
-        Todo::todoMimeType()
-    };
+    const QStringList mimeTypes{Event::eventMimeType(), Todo::todoMimeType()};
     mCalendar = Akonadi::ETMCalendar::Ptr(new Akonadi::ETMCalendar(mimeTypes));
     mCalendar->setObjectName(QStringLiteral("KOrgac's calendar"));
     mETM = mCalendar->entityTreeModel();
 
     connect(&mCheckTimer, &QTimer::timeout, this, &KOAlarmClient::checkAlarms);
-    connect(mETM, &Akonadi::EntityTreeModel::collectionPopulated,
-            this, &KOAlarmClient::deferredInit);
-    connect(mETM, &Akonadi::EntityTreeModel::collectionTreeFetched,
-            this, &KOAlarmClient::deferredInit);
+    connect(mETM, &Akonadi::EntityTreeModel::collectionPopulated, this, &KOAlarmClient::deferredInit);
+    connect(mETM, &Akonadi::EntityTreeModel::collectionTreeFetched, this, &KOAlarmClient::deferredInit);
 
     checkAlarms();
 }
@@ -137,8 +130,7 @@ void KOAlarmClient::deferredInit()
         if (akonadiItemId >= 0) {
             const QDateTime dt = incGroup.readEntry("RemindAt", QDateTime());
             Akonadi::Item i = mCalendar->item(Akonadi::Item::fromUrl(url).id());
-            if (CalendarSupport::hasIncidence(i)
-                && !CalendarSupport::incidence(i)->alarms().isEmpty()) {
+            if (CalendarSupport::hasIncidence(i) && !CalendarSupport::incidence(i)->alarms().isEmpty()) {
                 createReminder(i, dt, QString());
             }
         }
@@ -153,8 +145,7 @@ void KOAlarmClient::deferredInit()
 
 bool KOAlarmClient::dockerEnabled()
 {
-    KConfig korgConfig(QStandardPaths::locate(QStandardPaths::ConfigLocation, QStringLiteral(
-                                                  "korganizerrc")));
+    KConfig korgConfig(QStandardPaths::locate(QStandardPaths::ConfigLocation, QStringLiteral("korganizerrc")));
     KConfigGroup generalGroup(&korgConfig, "System Tray");
     return generalGroup.readEntry("ShowReminderDaemon", true);
 }
@@ -171,8 +162,7 @@ bool KOAlarmClient::collectionsAvailable() const
     for (int row = 0; row < rowCount; ++row) {
         static const int column = 0;
         const QModelIndex index = mETM->index(row, column);
-        const bool haveData
-            = mETM->data(index, Akonadi::EntityTreeModel::IsPopulatedRole).toBool();
+        const bool haveData = mETM->data(index, Akonadi::EntityTreeModel::IsPopulatedRole).toBool();
         if (!haveData) {
             return false;
         }
@@ -201,8 +191,7 @@ void KOAlarmClient::checkAlarms()
 
     qCDebug(KOALARMCLIENT_LOG) << "Check:" << from.toString() << " -" << mLastChecked.toString();
 
-    const Alarm::List alarms
-        = mCalendar->alarms(from, mLastChecked, true /* exclude blocked alarms */);
+    const Alarm::List alarms = mCalendar->alarms(from, mLastChecked, true /* exclude blocked alarms */);
 
     for (const Alarm::Ptr &alarm : alarms) {
         const QString uid = alarm->customProperty("ETMCalendar", "parentUid");
@@ -299,8 +288,7 @@ QStringList KOAlarmClient::dumpAlarms() const
     const Alarm::List alarms = mCalendar->alarms(start, end);
     lst.reserve(1 + (alarms.isEmpty() ? 1 : alarms.count()));
     // Don't translate, this is for debugging purposes.
-    lst << QStringLiteral("dumpAlarms() from ") + start.toString()
-        +QLatin1String(" to ") + end.toString();
+    lst << QStringLiteral("dumpAlarms() from ") + start.toString() + QLatin1String(" to ") + end.toString();
 
     if (alarms.isEmpty()) {
         lst << QStringLiteral("No alarm found.");
