@@ -11,7 +11,8 @@
 #include "korganizerprivate_export.h"
 #include <KAboutData>
 
-namespace KOrg {
+namespace KOrg
+{
 class KORGANIZERPRIVATE_EXPORT AboutData : public KAboutData
 {
 public:
