@@ -13,8 +13,8 @@
 #include "koglobals.h"
 #include "korganizer_debug.h"
 
-
-DateNavigator::DateNavigator(QObject *parent) : QObject(parent)
+DateNavigator::DateNavigator(QObject *parent)
+    : QObject(parent)
 {
     mSelectedDates.append(QDate::currentDate());
 }
@@ -23,7 +23,7 @@ DateNavigator::~DateNavigator()
 {
 }
 
-KCalendarCore::DateList DateNavigator::selectedDates()
+KCalendarCore::DateList DateNavigator::selectedDates() const
 {
     return mSelectedDates;
 }
@@ -74,8 +74,8 @@ void DateNavigator::selectDates(const QDate &d, int count, const QDate &preferre
 
 void DateNavigator::selectWeekByDay(int weekDay, QDate d, QDate preferredMonth)
 {
-    int dateCount = mSelectedDates.count();
-    bool weekStart = (weekDay == KOGlobals::self()->firstDayOfWeek());
+    const int dateCount = mSelectedDates.count();
+    const bool weekStart = (weekDay == KOGlobals::self()->firstDayOfWeek());
     if (weekStart && dateCount == 7) {
         selectWeek(d, preferredMonth);
     } else {
@@ -131,9 +131,9 @@ void DateNavigator::selectWorkWeek(QDate d)
 
 void DateNavigator::selectToday()
 {
-    QDate d = QDate::currentDate();
+    const QDate d = QDate::currentDate();
 
-    int dateCount = mSelectedDates.count();
+    const int dateCount = mSelectedDates.count();
 
     if (dateCount == 7) {
         selectWeek(d);
@@ -147,7 +147,7 @@ void DateNavigator::selectToday()
 void DateNavigator::selectPreviousYear()
 {
     QDate firstSelected = mSelectedDates.first();
-    int weekDay = firstSelected.dayOfWeek();
+    const int weekDay = firstSelected.dayOfWeek();
     firstSelected = firstSelected.addYears(-1);
 
     selectWeekByDay(weekDay, firstSelected);
@@ -155,10 +155,7 @@ void DateNavigator::selectPreviousYear()
 
 void DateNavigator::selectPreviousMonth(const QDate &currentMonth, const QDate &selectionLowerLimit, const QDate &selectionUpperLimit)
 {
-    shiftMonth(currentMonth,
-               selectionLowerLimit,
-               selectionUpperLimit,
-               -1);
+    shiftMonth(currentMonth, selectionLowerLimit, selectionUpperLimit, -1);
 }
 
 void DateNavigator::selectPreviousWeek()
@@ -206,10 +203,7 @@ void DateNavigator::shiftMonth(const QDate &currentMonth, const QDate &selection
 
 void DateNavigator::selectNextMonth(const QDate &currentMonth, const QDate &selectionLowerLimit, const QDate &selectionUpperLimit)
 {
-    shiftMonth(currentMonth,
-               selectionLowerLimit,
-               selectionUpperLimit,
-               1);
+    shiftMonth(currentMonth, selectionLowerLimit, selectionUpperLimit, 1);
 }
 
 void DateNavigator::selectNextYear()
