@@ -19,8 +19,8 @@
 
 #include <PimCommon/PimUtil>
 
-#include <KMessageBox>
 #include <KColorScheme>
+#include <KMessageBox>
 
 #include <QDialogButtonBox>
 
@@ -28,10 +28,9 @@ FilterEditDialog::FilterEditDialog(QList<KCalendarCore::CalFilter *> *filters, Q
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title::window", "Edit Calendar Filters"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(
-        QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Apply, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Apply, this);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     mApplyButton = buttonBox->button(QDialogButtonBox::Apply);
     mOkButton->setDefault(true);
@@ -45,9 +44,7 @@ FilterEditDialog::FilterEditDialog(QList<KCalendarCore::CalFilter *> *filters, Q
     updateFilterList();
     connect(mFilterEdit, &FilterEdit::editCategories, this, &FilterEditDialog::editCategories);
     connect(mFilterEdit, &FilterEdit::filterChanged, this, &FilterEditDialog::filterChanged);
-    connect(buttonBox->button(
-                QDialogButtonBox::Apply), &QPushButton::clicked, this,
-            &FilterEditDialog::slotApply);
+    connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, &FilterEditDialog::slotApply);
 }
 
 FilterEditDialog::~FilterEditDialog()
@@ -86,15 +83,10 @@ FilterEdit::FilterEdit(QList<KCalendarCore::CalFilter *> *filters, QWidget *pare
     new KPIM::LineEditCatchReturnKey(mNameLineEdit, this);
     mDetailsFrame->setEnabled(false);
     mFilters = filters;
-    mNewButton->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "Press this button to define a new filter."));
-    mDeleteButton->setWhatsThis(
-        i18nc("@info:whatsthis",
-              "Press this button to remove the currently active filter."));
+    mNewButton->setWhatsThis(i18nc("@info:whatsthis", "Press this button to define a new filter."));
+    mDeleteButton->setWhatsThis(i18nc("@info:whatsthis", "Press this button to remove the currently active filter."));
 
-    connect(mRulesList, qOverload<>(&QListWidget::itemSelectionChanged),
-            this, qOverload<>(&FilterEdit::filterSelected));
+    connect(mRulesList, &QListWidget::itemSelectionChanged, this, qOverload<>(&FilterEdit::filterSelected));
 
     connect(mNewButton, &QPushButton::clicked, this, &FilterEdit::bNewPressed);
     connect(mDeleteButton, &QPushButton::clicked, this, &FilterEdit::bDeletePressed);
@@ -201,10 +193,8 @@ void FilterEdit::filterSelected(KCalendarCore::CalFilter *filter)
     mCompletedCheck->setChecked(mCurrent->criteria() & KCalendarCore::CalFilter::HideCompletedTodos);
     mCompletedTimeSpan->setValue(mCurrent->completedTimeSpan());
     mRecurringCheck->setChecked(mCurrent->criteria() & KCalendarCore::CalFilter::HideRecurring);
-    mHideInactiveTodosCheck->setChecked(
-        mCurrent->criteria() & KCalendarCore::CalFilter::HideInactiveTodos);
-    mHideTodosNotAssignedToMeCheck->setChecked(
-        mCurrent->criteria() & KCalendarCore::CalFilter::HideNoMatchingAttendeeTodos);
+    mHideInactiveTodosCheck->setChecked(mCurrent->criteria() & KCalendarCore::CalFilter::HideInactiveTodos);
+    mHideTodosNotAssignedToMeCheck->setChecked(mCurrent->criteria() & KCalendarCore::CalFilter::HideNoMatchingAttendeeTodos);
 
     if (mCurrent->criteria() & KCalendarCore::CalFilter::ShowCategories) {
         mCatShowCheck->setChecked(true);
@@ -227,15 +217,13 @@ void FilterEdit::bNewPressed()
     }
     QString newFilterName;
     for (int i = 1;; ++i) {
-        newFilterName = i18nc("@label default filter name",
-                              "New Filter %1", i);
+        newFilterName = i18nc("@label default filter name", "New Filter %1", i);
         if (!filterNames.contains(newFilterName)) {
             break;
         }
     }
 
-    auto *newFilter
-        = new KCalendarCore::CalFilter(newFilterName);
+    auto newFilter = new KCalendarCore::CalFilter(newFilterName);
     mFilters->append(newFilter);
     updateFilterList();
     mRulesList->setCurrentRow(mRulesList->count() - 1);
@@ -244,19 +232,18 @@ void FilterEdit::bNewPressed()
 
 void FilterEdit::bDeletePressed()
 {
-    if (!mRulesList->currentItem()) {   // nothing selected
+    if (!mRulesList->currentItem()) { // nothing selected
         return;
     }
-    if (mFilters->isEmpty()) {   // We need at least a default filter object.
+    if (mFilters->isEmpty()) { // We need at least a default filter object.
         return;
     }
 
-    if (KMessageBox::warningContinueCancel(
-            this,
-            i18nc("@info",
-                  "Do you really want to permanently remove the filter \"%1\"?", mCurrent->name()),
-            i18nc("@title:window", "Delete Filter?"),
-            KStandardGuiItem::del()) == KMessageBox::Cancel) {
+    if (KMessageBox::warningContinueCancel(this,
+                                           i18nc("@info", "Do you really want to permanently remove the filter \"%1\"?", mCurrent->name()),
+                                           i18nc("@title:window", "Delete Filter?"),
+                                           KStandardGuiItem::del())
+        == KMessageBox::Cancel) {
         return;
     }
 
@@ -299,11 +286,8 @@ bool FilterEdit::correctName(const QString &newText)
 #ifndef QT_NO_STYLE_STYLESHEET
     QString styleSheet;
     if (mNegativeBackground.isEmpty()) {
-        const KStatefulBrush bgBrush = KStatefulBrush(KColorScheme::View,
-                                                      KColorScheme::NegativeBackground);
-        mNegativeBackground
-            = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(
-                                                                         mNameLineEdit).color().name());
+        const KStatefulBrush bgBrush = KStatefulBrush(KColorScheme::View, KColorScheme::NegativeBackground);
+        mNegativeBackground = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(mNameLineEdit).color().name());
     }
     if (!newText.isEmpty()) {
         const int val = mRulesList->count();
@@ -337,19 +321,15 @@ void FilterEdit::editCategorySelection()
         mCategorySelectDialog = new Akonadi::TagSelectionDialog(this);
         QDialogButtonBox *buttons = mCategorySelectDialog->buttons();
         if (buttons) {
-            buttons->setStandardButtons(
-                QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help);
-            connect(mCategorySelectDialog, &Akonadi::TagSelectionDialog::accepted,
-                    this, &FilterEdit::updateCategorySelection);
-            connect(buttons->button(QDialogButtonBox::Help), &QPushButton::clicked,
-                    this, &FilterEdit::slotHelp);
+            buttons->setStandardButtons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help);
+            connect(mCategorySelectDialog, &Akonadi::TagSelectionDialog::accepted, this, &FilterEdit::updateCategorySelection);
+            connect(buttons->button(QDialogButtonBox::Help), &QPushButton::clicked, this, &FilterEdit::slotHelp);
         }
     }
     Akonadi::Tag::List tags;
     const auto names = mCurrent->categoryList();
     tags.resize(names.size());
-    std::transform(names.cbegin(), names.cend(), std::back_inserter(tags),
-                   [](const QString &name) {
+    std::transform(names.cbegin(), names.cend(), std::back_inserter(tags), [](const QString &name) {
         return Akonadi::Tag{name};
     });
     mCategorySelectDialog->setSelection(tags);
@@ -367,8 +347,7 @@ void FilterEdit::updateCategorySelection()
     const auto tags = mCategorySelectDialog->selection();
     QStringList categories;
     categories.reserve(tags.size());
-    std::transform(tags.cbegin(), tags.cend(), std::back_inserter(categories),
-                   std::bind(&Akonadi::Tag::name, std::placeholders::_1));
+    std::transform(tags.cbegin(), tags.cend(), std::back_inserter(categories), std::bind(&Akonadi::Tag::name, std::placeholders::_1));
     mCatList->clear();
     mCatList->addItems(categories);
     mCurrent->setCategoryList(categories);
