@@ -11,12 +11,13 @@
 
 #include "mainwindow.h"
 
-#include <KPluginFactory>
 #include <KParts/Part>
+#include <KPluginFactory>
 
 #include <QWidget>
 
-namespace KOrg {
+namespace KOrg
+{
 class Part : public KParts::Part
 {
     Q_OBJECT
@@ -39,7 +40,7 @@ public:
     {
     }
 
-    virtual ~Part()
+    ~Part() override
     {
     }
 
@@ -54,7 +55,7 @@ public:
     }
 
 private:
-    MainWindow *mMainWindow = nullptr;
+    MainWindow *const mMainWindow;
 };
 
 class PartFactory : public KPluginFactory
