@@ -13,8 +13,7 @@
 #include "ui_todosummaryconfig_base.h"
 #include <KCModule>
 
-extern "C"
-{
+extern "C" {
 Q_DECL_EXPORT KCModule *create_todosummary(QWidget *parent, const char *);
 }
 
