@@ -17,13 +17,13 @@ class QDate;
 class SummaryEventInfo
 {
 public:
-
     using List = QList<SummaryEventInfo *>;
 
     SummaryEventInfo();
 
     static List eventsForDate(const QDate &date, const Akonadi::ETMCalendar::Ptr &calendar);
-    static List eventsForRange(const QDate &start, const QDate &end, // range is inclusive
+    static List eventsForRange(const QDate &start,
+                               const QDate &end, // range is inclusive
                                const Akonadi::ETMCalendar::Ptr &calendar);
     static void setShowSpecialEvents(bool skipBirthdays, bool skipAnniversaries);
 
@@ -35,8 +35,8 @@ public:
     QString summaryText;
     QString summaryUrl;
     QString summaryTooltip;
-    bool makeBold;
-    bool makeUrgent;
+    bool makeBold = false;
+    bool makeUrgent = false;
 
 private:
     static bool skip(const KCalendarCore::Event::Ptr &event);
