@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -15,12 +15,10 @@ KOrgMigrateApplication::KOrgMigrateApplication()
 
 void KOrgMigrateApplication::migrate()
 {
-    //Migrate to xdg
+    // Migrate to xdg
     Kdelibs4ConfigMigrator migrate(QStringLiteral("korganizer"));
-    migrate.setConfigFiles(QStringList() << QStringLiteral("korganizerrc")
-                                         << QStringLiteral("freebusyurls"));
-    migrate.setUiFiles(QStringList() << QStringLiteral("korganizer_part.rc")
-                                     << QStringLiteral("korganizerui.rc"));
+    migrate.setConfigFiles(QStringList() << QStringLiteral("korganizerrc") << QStringLiteral("freebusyurls"));
+    migrate.setUiFiles(QStringList() << QStringLiteral("korganizer_part.rc") << QStringLiteral("korganizerui.rc"));
     migrate.migrate();
 
     // Migrate folders and files.
@@ -55,6 +53,6 @@ void KOrgMigrateApplication::initializeMigrator()
     migrateInfoDesigner.setVersion(initialVersion);
     mMigrator.insertMigrateInfo(migrateInfoDesigner);
 
-    //TODO add folder to migrate
+    // TODO add folder to migrate
     // If you add new MigrateFileInfo we need to increase "currentVersion"  and initialVersion
 }
