@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,15 +7,15 @@
 #ifndef KORGANIZERUSERFEEDBACKPROVIDER_H
 #define KORGANIZERUSERFEEDBACKPROVIDER_H
 
-#include <KUserFeedback/Provider>
 #include "korganizerprivate_export.h"
+#include <KUserFeedback/Provider>
 
 class KORGANIZERPRIVATE_EXPORT KOrganizerUserFeedbackProvider : public KUserFeedback::Provider
 {
     Q_OBJECT
 public:
     explicit KOrganizerUserFeedbackProvider(QObject *parent = nullptr);
-    ~KOrganizerUserFeedbackProvider();
+    ~KOrganizerUserFeedbackProvider() override;
 };
 
 #endif // KORGANIZERUSERFEEDBACKPROVIDER_H
