@@ -12,7 +12,8 @@
 #include "baseview.h"
 #include <KCalendarCore/Incidence> // for KCalendarCore::DateList typedef
 
-namespace EventViews {
+namespace EventViews
+{
 class JournalView;
 }
 
@@ -51,13 +52,12 @@ public Q_SLOTS:
     void showDates(const QDate &start, const QDate &end, const QDate &preferredMonth = QDate()) override;
     void showIncidences(const Akonadi::Item::List &incidences, const QDate &date) override;
 
-    void changeIncidenceDisplay(const Akonadi::Item &incidence,
-                                Akonadi::IncidenceChanger::ChangeType) override;
+    void changeIncidenceDisplay(const Akonadi::Item &incidence, Akonadi::IncidenceChanger::ChangeType) override;
     void setIncidenceChanger(Akonadi::IncidenceChanger *changer) override;
     void printJournal(const KCalendarCore::Journal::Ptr &journal, bool preview);
 
 private:
-    EventViews::JournalView *mJournalView = nullptr;
+    EventViews::JournalView *const mJournalView;
 };
 
 #endif
